SimaiException class

Implemented types
Implementers

Constructors

SimaiException(int line, int character)
line The line on which the error occurred character The first character involved in the error

Properties

character int
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited