SimaiGameplayCenterDisplayMode enum
Values
- achievementAdd → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('达成率 0%+') - achievement101Subtract → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('达成率 101%-') - achievement100Subtract → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('达成率 100%-') - combo → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('Combo') - dxScoreAdd → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('DX 分数 0+') - dxScoreSubtract → const SimaiGameplayCenterDisplayMode
-
const SimaiGameplayCenterDisplayMode('DX 分数 max-')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SimaiGameplayCenterDisplayMode> - A constant List of the values in this enum, in order of their declaration.