SimaiGameplaySettings class

Annotations

Constructors

SimaiGameplaySettings({double noteSpeed = 8.0, int musicOffsetMs = 0, int judgementOffsetMs = 0, double musicVolume = 0.8, double hitSoundVolume = 0.72, bool hitSoundEnabled = true, SimaiMirrorMode mirrorMode = SimaiMirrorMode.none, SimaiBackgroundMode backgroundMode = SimaiBackgroundMode.judgeZone, SimaiJudgementDisplayMode judgementDisplayMode = SimaiJudgementDisplayMode.twoB, SimaiGameplayCenterDisplayMode centerDisplayMode = SimaiGameplayCenterDisplayMode.achievementAdd, bool showApproachLine = true, bool showHitEffects = true, bool showInputPartitions = false, bool showTouchIndicators = true})
const

Properties

approachTime double
no setter
backgroundMode SimaiBackgroundMode
final
centerDisplayMode SimaiGameplayCenterDisplayMode
final
hashCode int
The hash code for this object.
no setteroverride
hitSoundEnabled bool
final
hitSoundVolume double
final
judgementDisplayMode SimaiJudgementDisplayMode
final
judgementOffsetMs int
final
mirrorMode SimaiMirrorMode
final
musicOffsetMs int
final
musicVolume double
final
noteSpeed double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showApproachLine bool
final
showHitEffects bool
final
showInputPartitions bool
final
showTouchIndicators bool
final

Methods

copyWith({double? noteSpeed, int? musicOffsetMs, int? judgementOffsetMs, double? musicVolume, double? hitSoundVolume, bool? hitSoundEnabled, SimaiMirrorMode? mirrorMode, SimaiBackgroundMode? backgroundMode, SimaiJudgementDisplayMode? judgementDisplayMode, SimaiGameplayCenterDisplayMode? centerDisplayMode, bool? showApproachLine, bool? showHitEffects, bool? showInputPartitions, bool? showTouchIndicators}) SimaiGameplaySettings
normalized() SimaiGameplaySettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override