SimaiJudgementRecord class

Annotations

Constructors

SimaiJudgementRecord({required int collectionIndex, required int noteIndex, required int? slidePathIndex, required double targetTime, required double judgedTime, required double offsetSeconds, required SimaiJudgeGrade grade, required SimaiJudgeBand? band, required SimaiJudgeTiming timing, required SimaiGameplayScoringType scoringType, required bool isAuto, bool holdAdjusted = false, bool isGroupAssisted = false})
const

Properties

band SimaiJudgeBand?
final
collectionIndex int
final
grade SimaiJudgeGrade
final
hashCode int
The hash code for this object.
no setterinherited
holdAdjusted bool
final
isAuto bool
final
isGroupAssisted bool
final
isMiss bool
no setter
judgedTime double
final
noteIndex int
final
offsetSeconds double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoringType SimaiGameplayScoringType
final
slidePathIndex int?
final
targetTime double
final
timing SimaiJudgeTiming
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited