SimaiMirrorUtils class
Majdata-compatible mirror transforms shared by playback, gameplay input, slide precomputation and video export.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mirrorLocation(
Location location, SimaiMirrorMode mode) → Location -
mirrorSlideType(
SlideType type, SimaiMirrorMode mode) → SlideType -
mirrorTapLane(
int lane, SimaiMirrorMode mode) → int