SimaiTapJudgement class

Constructors

SimaiTapJudgement({required SimaiJudgeGrade grade, required SimaiJudgeBand band, required SimaiJudgeTiming timing, required double offsetSeconds})
const

Properties

band SimaiJudgeBand
final
grade SimaiJudgeGrade
final
hashCode int
The hash code for this object.
no setterinherited
offsetSeconds double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timing SimaiJudgeTiming
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited