UnsupportedSyntaxException class

Inheritance

Constructors

UnsupportedSyntaxException(int line, int character)
This is thrown when an unsupported syntax is encountered when attempting to tokenize or deserialize the simai file.

Properties

character int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
line int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited