SimaiGameplayResult class
- Annotations
Constructors
-
SimaiGameplayResult({required SimaiGameplaySettings settings, required List<
SimaiJudgementRecord> judgements, required double achievement, required int dxScore, required int totalDxScore, required int maxCombo, required int fastCount, required int lateCount, required double averageManualOffsetMs, required int autoAssistCount, required SimaiGameplayClearType clearType, required Map<SimaiJudgeGrade, int> gradeCounts, required Map<SimaiGameplayScoringType, int> typeCounts}) -
const
Properties
- achievement → double
-
final
- autoAssistCount → int
-
final
- averageManualOffsetMs → double
-
final
- clearType → SimaiGameplayClearType
-
final
- dxScore → int
-
final
- fastCount → int
-
final
-
gradeCounts
→ Map<
SimaiJudgeGrade, int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAutoAssisted → bool
-
no setter
-
judgements
→ List<
SimaiJudgementRecord> -
final
- lateCount → int
-
final
- maxCombo → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → SimaiGameplaySettings
-
final
- totalDxScore → int
-
final
- totalNoteCount → int
-
no setter
- touchGroupAssistCount → int
-
no setter
-
typeCounts
→ Map<
SimaiGameplayScoringType, int> -
final
Methods
-
countForGrade(
SimaiJudgeGrade grade) → int -
countForType(
SimaiGameplayScoringType type) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited