UnsupportedSyntaxException class
- Inheritance
-
- Object
- SimaiException
- UnsupportedSyntaxException
Constructors
- UnsupportedSyntaxException(int line, int character)
- This is thrown when an unsupported syntax is encountered when attempting to tokenize or deserialize the simai file.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited